@@ -117,6 +117,7 @@ class PasaffeWindow(Window):
             self.display_entries()
             self.set_initial_tree_expansion()
             self.display_welcome()
+            self.ui.treeview1.grab_focus()
 
         # Set inactivity timer
         self.set_idle_timeout()
@@ -162,6 +163,7 @@ class PasaffeWindow(Window):
     def save_warning(self):
         if self.get_save_status() == True:
             savechanges_dialog = self.SaveChangesDialog()
+            savechanges_dialog.set_transient_for(self)
             response = savechanges_dialog.run()
             if response == Gtk.ResponseType.OK:
                 self.save_db()
@@ -173,6 +175,7 @@ class PasaffeWindow(Window):
     def fetch_password(self):
         success = True
         password_dialog = self.PasswordEntryDialog()
+        password_dialog.set_transient_for(self)
         while self.passfile == None:
             response = password_dialog.run()
             if response == Gtk.ResponseType.OK:
@@ -192,6 +195,7 @@ class PasaffeWindow(Window):
     def new_database(self):
         success = False
         newdb_dialog = self.NewDatabaseDialog()
+        newdb_dialog.set_transient_for(self)
         while success == False:
             response = newdb_dialog.run()
             if response == Gtk.ResponseType.OK:
@@ -422,7 +426,6 @@ class PasaffeWindow(Window):
             self.display_data(uuid)
             path = treemodel.get_path(item)
             self.ui.treeview1.scroll_to_cell(path)
-            self.set_menu_for_entry(True)
 
     def goto_folder(self, folders):
         item = self.search_folder(folders)
@@ -431,7 +434,6 @@ class PasaffeWindow(Window):
             self.display_folder(self.ui.liststore1.get_value(item, 1))
             path = self.ui.treeview1.get_model().get_path(item)
             self.ui.treeview1.scroll_to_cell(path)
-            self.set_menu_for_entry(False)
 
     def search_uuid(self, uuid, item=None, toplevel=True):
        if toplevel == True:
@@ -567,6 +569,26 @@ class PasaffeWindow(Window):
 
         self.ui.textview1.set_buffer(data_buffer)
 
+        self.set_menu_for_entry(True)
+
+        # Now disable menus for blank entries
+        if self.passfile.records[entry_uuid].get(13) in [ None, "" ]:
+            self.ui.url_copy.set_sensitive(False)
+            self.ui.mnu_open_url.set_sensitive(False)
+            self.ui.url_copy1.set_sensitive(False)
+            self.ui.open_url.set_sensitive(False)
+
+        if self.passfile.records[entry_uuid].get(4) in [ None, "" ]:
+            self.ui.username_copy.set_sensitive(False)
+            self.ui.username_copy1.set_sensitive(False)
+            self.ui.copy_username.set_sensitive(False)
+
+        if self.passfile.records[entry_uuid].get(6) in [ None, "" ]:
+            self.ui.password_copy.set_sensitive(False)
+            self.ui.password_copy1.set_sensitive(False)
+            self.ui.copy_password.set_sensitive(False)
+
+
     def display_welcome(self):
         ttt = self.get_texttagtable()
         data_buffer = Gtk.TextBuffer.new(ttt)
@@ -596,6 +618,7 @@ class PasaffeWindow(Window):
                            _("This is a folder."))
 
         self.ui.textview1.set_buffer(data_buffer)
+        self.set_menu_for_entry(False)
 
     def get_texttagtable(self):
         texttagtable = Gtk.TextTagTable()
@@ -660,10 +683,8 @@ class PasaffeWindow(Window):
                 entry_uuid = treemodel.get_value(treeiter, 2)
                 if "pasaffe_treenode." in entry_uuid:
                     self.display_folder(treemodel.get_value(treeiter, 1))
-                    self.set_menu_for_entry(False)
                 else:
                     self.display_data(entry_uuid)
-                    self.set_menu_for_entry(True)
 
                 # Reset the show password button and menu item
                 self.ui.display_secrets.set_active(False)
@@ -740,7 +761,6 @@ class PasaffeWindow(Window):
 
         self.ui.treeview1.get_selection().select_iter(new_iter)
         self.display_folder(self.ui.liststore1.get_value(new_iter, 1))
-        self.set_menu_for_entry(False)
 
         new_folder = self.get_folders_from_iter(treemodel, new_iter)
         response = self.edit_folder(self.ui.liststore1, new_iter, True)
@@ -877,6 +897,7 @@ class PasaffeWindow(Window):
                     self.editdetails_dialog.builder.get_object(widget_name).set_text(self.passfile.records[entry_uuid][record_type])
 
             self.set_entry_window_size()
+            self.editdetails_dialog.set_transient_for(self)
             response = self.editdetails_dialog.run()
 
             data_changed = False
@@ -938,7 +959,6 @@ class PasaffeWindow(Window):
                 treemodel, treeiter = self.ui.treeview1.get_selection().get_selected()
                 if treeiter != None and treemodel.get_value(treeiter, 2) == entry_uuid:
                     self.display_data(entry_uuid)
-                    self.set_menu_for_entry(True)
 
             self.set_idle_timeout()
             self.update_find_results(force=True)
@@ -969,6 +989,7 @@ class PasaffeWindow(Window):
             self.populate_folders(liststore, combobox, parent_folder)
 
             self.set_folder_window_size()
+            self.editfolder_dialog.set_transient_for(self)
             response = self.editfolder_dialog.run()
             if response == Gtk.ResponseType.OK:
                 new_name = self.editfolder_dialog.ui.folder_name_entry.get_text()
@@ -1060,10 +1081,8 @@ class PasaffeWindow(Window):
             entry_uuid = treemodel.get_value(treeiter, 2)
             if "pasaffe_treenode." in entry_uuid:
                 self.display_folder(treemodel.get_value(treeiter, 1))
-                self.set_menu_for_entry(False)
             else:
                 self.display_data(entry_uuid)
-                self.set_menu_for_entry(True)
         else:
             self.display_welcome()
 
@@ -1092,10 +1111,8 @@ class PasaffeWindow(Window):
             entry_uuid = treemodel.get_value(treeiter, 2)
             if "pasaffe_treenode." in entry_uuid:
                 self.display_folder(treemodel.get_value(treeiter, 1))
-                self.set_menu_for_entry(False)
             else:
                 self.display_data(entry_uuid)
-                self.set_menu_for_entry(True)
         else:
             self.display_welcome()
 
@@ -1377,6 +1394,8 @@ class PasaffeWindow(Window):
     def on_mnu_chg_password_activate(self, _menuitem):
         success = False
         newpass_dialog = self.NewPasswordDialog()
+        newpass_dialog.set_transient_for(self)
+
         while success == False:
             response = newpass_dialog.run()
             if response == Gtk.ResponseType.OK:
