@@ -72,6 +72,7 @@ class Window(Gtk.Window):
         """Display the about box for pasaffe."""
         if self.AboutDialog is not None:
             about = self.AboutDialog()  # pylint: disable=E1102
+            about.set_transient_for(self)
             response = about.run()
             about.destroy()
 
@@ -90,6 +91,7 @@ class Window(Gtk.Window):
             logger.debug('create new preferences_dialog')
             self.preferences_dialog = \
                 self.PreferencesDialog()  # pylint: disable=E1102
+            self.preferences_dialog.set_transient_for(self)
             self.preferences_dialog.connect('destroy',
                 self.on_preferences_dialog_destroyed)
             self.preferences_dialog.show()
