@@ -99,7 +99,7 @@ class TestPasswordGorilla15363(unittest.TestCase):
         self.assertEqual(self.passfile.records[uuid][3], 'entrylevel1')
         self.assertEqual(self.passfile.records[uuid][4], 'username1')
         self.assertEqual(self.passfile.records[uuid][5],
-                         'This is a note\r\nThis is a second line\r\nUnicode: éléphant')
+                         'This is a note\nThis is a second line\nUnicode: éléphant')
         self.assertEqual(self.passfile.records[uuid][6], 'password1')
         self.assertEqual(self.passfile.get_password_time(uuid, False),
                          'Thu, 25 Jul 2013 00:33:06')
